RemoteGraphicsView — pyqtgraph 0.11.0rc0 documentation

# RemoteGraphicsView

class `pyqtgraph.widgets.RemoteGraphicsView.` `RemoteGraphicsView`(parent=None, *args, **kwds)

  Replacement for GraphicsView that does all scene management and rendering on a remote process, while displaying on the local widget.

  GraphicsItems must be created by proxy to the remote process.

  `__init__`(parent=None, *args, **kwds)

    The keyword arguments ‘useOpenGL’ and ‘backgound’, if specified, are passed to the remote GraphicsView.__init__(). All other keyword arguments are passed to multiprocess.QtProcess.__init__().

  `close`()

    Close the remote process. After this call, the widget will no longer be updated.

  `enterEvent`(self, event: PySide2.QtCore.QEvent)
  `leaveEvent`(self, event: PySide2.QtCore.QEvent)
  `mouseMoveEvent`(self, event: PySide2.QtGui.QMouseEvent)
  `mousePressEvent`(self, event: PySide2.QtGui.QMouseEvent)
  `mouseReleaseEvent`(self, event: PySide2.QtGui.QMouseEvent)
  `paintEvent`(self, event: PySide2.QtGui.QPaintEvent)
  `remoteProcess`()

    Return the remote process handle. (see multiprocess.remoteproxy.RemoteEventHandler)

  `resizeEvent`(self, event: PySide2.QtGui.QResizeEvent)
  `sizeHint`(self) → PySide2.QtCore.QSize
  `wheelEvent`(self, event: PySide2.QtGui.QWheelEvent)